##  Modeling Guidelines
Model each AI agent using a separate fact sheet. This enables you to efficiently use dedicated reports, dashboards, diagrams, and other features.
Add relations to other architectural elements:
  * Link AI agents to IT components and business capabilities.
  * When applicable, link AI agents to relevant business applications. This provides the needed business context for AI agents, which helps ensure an efficient adoption of AI agents.


Modeling example:
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio171ad151bf7949c28545f59685adaf0d_LowRes.png)
Modeling AI Agents: Example
